@@ -1,26 +1,13 @@
+// SPDX-License-Identifier: LGPL-2.1+
 /* NetworkManager Applet -- allow user control over networking
  *
  * Lubomir Rintel <lkundrak@v3.sk>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301 USA.
- *
  * Copyright (C) 2017,2018 Red Hat, Inc.
  */
 
 #include "nm-default.h"
+#include "nma-private.h"
 #include "nma-cert-chooser-private.h"
 #include "nma-cert-chooser-button.h"
 #include "nma-ui-utils.h"
@@ -41,7 +28,7 @@ set_key_password (NMACertChooser *cert_chooser, const gchar *password)
 
 	g_return_if_fail (priv->key_password != NULL);
 	if (password)
-		gtk_entry_set_text (GTK_ENTRY (priv->key_password), password);
+		gtk_editable_set_text (GTK_EDITABLE (priv->key_password), password);
 }
 
 static const gchar *
@@ -51,7 +38,7 @@ get_key_password (NMACertChooser *cert_chooser)
 	const gchar *text;
 
 	g_return_val_if_fail (priv->key_password != NULL, NULL);
-	text = gtk_entry_get_text (GTK_ENTRY (priv->key_password));
+	text = gtk_editable_get_text (GTK_EDITABLE (priv->key_password));
 
 	return text && text[0] ? text : NULL;
 }
@@ -86,7 +73,7 @@ set_cert_password (NMACertChooser *cert_chooser, const gchar *password)
 
 	g_return_if_fail (priv->cert_password != NULL);
 	if (password)
-		gtk_entry_set_text (GTK_ENTRY (priv->cert_password), password);
+		gtk_editable_set_text (GTK_EDITABLE (priv->cert_password), password);
 }
 
 static const gchar *
@@ -96,7 +83,7 @@ get_cert_password (NMACertChooser *cert_chooser)
 	const gchar *text;
 
 	g_return_val_if_fail (priv->cert_password != NULL, NULL);
-	text = gtk_entry_get_text (GTK_ENTRY (priv->cert_password));
+	text = gtk_editable_get_text (GTK_EDITABLE (priv->cert_password));
 
 	return text && text[0] ? text : NULL;
 }
@@ -295,7 +282,7 @@ cert_changed_cb (NMACertChooserButton *button, gpointer user_data)
 	if (nma_cert_chooser_button_get_remember_pin (button))
 		pin = nma_cert_chooser_button_get_pin (button);
 	if (pin)
-		gtk_entry_set_text (GTK_ENTRY (priv->cert_password), pin);
+		gtk_editable_set_text (GTK_EDITABLE (priv->cert_password), pin);
 
 	gtk_widget_set_sensitive (priv->cert_password, uri_data != NULL);
 	gtk_widget_set_sensitive (priv->cert_password_label, uri_data != NULL);
@@ -311,7 +298,7 @@ cert_changed_cb (NMACertChooserButton *button, gpointer user_data)
 				gtk_widget_set_sensitive (priv->key_password, TRUE);
 				gtk_widget_set_sensitive (priv->key_password_label, TRUE);
 				if (pin)
-					gtk_entry_set_text (GTK_ENTRY (priv->key_password), pin);
+					gtk_editable_set_text (GTK_EDITABLE (priv->key_password), pin);
 			}
 		}
 	}
@@ -333,7 +320,7 @@ key_changed_cb (NMACertChooserButton *button, gpointer user_data)
 	if (nma_cert_chooser_button_get_remember_pin (button))
 		pin = nma_cert_chooser_button_get_pin (button);
 	if (pin) {
-		gtk_entry_set_text (GTK_ENTRY (priv->key_password), pin);
+		gtk_editable_set_text (GTK_EDITABLE (priv->key_password), pin);
 		g_free (pin);
 	}
 
